Documentation
¶
Index ¶
- type AccessTokenValidatorView
- type AccessTokenValidatorsView
- type AcmeAccountView
- type AcmeCertStatusView
- type AcmeCertificateRequestView
- type AcmeServerView
- type AcmeServersView
- type AdminBasicWebSessionView
- type AdminConfigurationView
- type AdminTokenProviderView
- type AdminWebSessionOidcConfigurationView
- type AgentCertificateView
- type AgentCertificatesView
- type AgentView
- type AgentsView
- type AlgorithmView
- type AlgorithmsView
- type ApiErrorView
- type ApplicationView
- type ApplicationsView
- type AttributeView
- type AuthTokenManagementView
- type AuthenticationChallengePoliciesView
- type AuthenticationChallengePolicyView
- type AuthnReqListView
- type AuthnReqListsView
- type AuthorizationServerView
- type AvailabilityProfileView
- type AvailabilityProfilesView
- type BasicAuthConfigView
- type BasicConfig
- type CSRResponseImportDocView
- type ChainCertificateView
- type ChainCertificatesDocView
- type ChallengeResponseFilterView
- type ChallengeResponseGeneratorView
- type ChallengeResponseMappingView
- type ChallengeResponseView
- type ConfigStatusView
- type ConfigStatusesView
- type ConfigurationDependentFieldOption
- type ConfigurationField
- type ConfigurationOption
- type ConfigurationParentField
- type CookieTypesView
- type DescriptorView
- type DescriptorsView
- type EmbeddableAccessTokenValidatorView
- type EngineCertificateView
- type EngineHealthStatusView
- type EngineInfo
- type EngineListenerView
- type EngineListenersView
- type EngineView
- type EnginesView
- type EnvironmentView
- type ExportData
- type ExportParameters
- type GeneralName
- type GlobalUnprotectedResourceView
- type GlobalUnprotectedResourcesView
- type Hash
- type Help
- type HiddenFieldView
- type HostMultiValueSourceView
- type HostPortView
- type HsmProviderView
- type HttpClientProxyView
- type HttpMonitoringView
- type HttpsListenerView
- type HttpsListenersView
- type IdentityMappingView
- type IdentityMappingsView
- type IpMultiValueSourceView
- type ItemView
- type JsonWebKey
- type Key
- type KeyAlgorithm
- type KeyAlgorithmsView
- type KeyPairView
- type KeyPairsView
- type KeySetView
- type LicenseImportDocView
- type LicenseView
- type LinkView
- type List
- type LoadBalancingStrategiesView
- type LoadBalancingStrategyView
- type MasterKeysView
- type MethodView
- type MethodsView
- type NewKeyPairConfigView
- type OAuthClientCredentialsView
- type OAuthConfigView
- type OAuthKeyManagementView
- type OIDCProviderMetadata
- type OIDCProviderPluginView
- type OIDCProviderView
- type OidcConfigView
- type OidcLoginTypesView
- type OptionalAttributeMappingView
- type PKCS12FileImportDocView
- type PathPatternView
- type PingFederateAccessTokenView
- type PingFederateAdminView
- type PingFederateMetadataRuntimeView
- type PingFederateRuntimeApplicationView
- type PingFederateRuntimeView
- type PingOne4CView
- type PolicyItem
- type ProblemDocumentView
- type ProtocolSourceView
- type PublicKey
- type PublicKeyView
- type QueryParamConfigView
- type QueryParamNameView
- type QueryParamPairView
- type QueryParamValueView
- type QueryParameterView
- type RedirectView
- type RedirectsView
- type RejectionHandlerView
- type RejectionHandlersView
- type ReplicaAdminView
- type ReplicaAdminsView
- type RequestMatcherView
- type RequestPreservationTypesView
- type RequiredAttributeMappingView
- type ReservedApplicationView
- type ResourceMatchingEntryView
- type ResourceMatchingEvaluationOrderView
- type ResourceOrderView
- type ResourceTypeConfigurationView
- type ResourceView
- type ResourcesView
- type ResponseGeneratorView
- type RevocationCheckingView
- type RoleMappingConfigurationView
- type RuleDescriptorView
- type RuleDescriptorsView
- type RuleSetElementTypesView
- type RuleSetSuccessCriteriaView
- type RuleSetView
- type RuleSetsView
- type RuleView
- type RulesView
- type SanType
- type SanTypes
- type SessionInfo
- type SharedSecretView
- type SharedSecretsView
- type SigningAlgorithmsView
- type SiteAuthenticatorView
- type SiteAuthenticatorsView
- type SiteView
- type SitesView
- type SupportedScopesView
- type TargetHostPortView
- type ThirdPartyServiceView
- type ThirdPartyServicesView
- type TokenProviderSettingView
- type TrustedCertView
- type TrustedCertificateGroupView
- type TrustedCertificateGroupsView
- type TrustedCertsView
- type UnknownResourceSettingsView
- type UserPasswordView
- type UserView
- type UsersView
- type VersionDocClass
- type VirtualHostView
- type VirtualHostsView
- type WebSessionManagementView
- type WebSessionView
- type WebSessionsView
- type WebStorageTypesView
- type X509FileImportDocView
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AccessTokenValidatorView ¶
type AccessTokenValidatorView struct {
ClassName *string `json:"className"`
Configuration map[string]interface{} `json:"configuration"`
Id json.Number `json:"id,omitempty"`
Name *string `json:"name"`
}
AccessTokenValidatorView - An access token validator.
type AccessTokenValidatorsView ¶
type AccessTokenValidatorsView struct {
Items []*AccessTokenValidatorView `json:"items"`
}
AccessTokenValidatorsView - A collection of access token validators.
type AcmeAccountView ¶
type AcmeAccountView struct {
AcmeServerId *string `json:"acmeServerId,omitempty"`
Id *string `json:"id,omitempty"`
KeyAlgorithm *string `json:"keyAlgorithm,omitempty"`
PrivateKey *HiddenFieldView `json:"privateKey,omitempty"`
PublicKey *PublicKeyView `json:"publicKey,omitempty"`
Url *string `json:"url,omitempty"`
}
AcmeAccountView - An ACME Account associated with a CA.
type AcmeCertStatusView ¶
type AcmeCertStatusView struct {
Problems map[string]*ProblemDocumentView `json:"problems,omitempty"`
State *string `json:"state"`
}
AcmeCertStatusView - The status of a certificate.
type AcmeCertificateRequestView ¶
type AcmeCertificateRequestView struct {
AcmeAccountId *string `json:"acmeAccountId,omitempty"`
AcmeCertStatus *AcmeCertStatusView `json:"acmeCertStatus,omitempty"`
AcmeServerId *string `json:"acmeServerId,omitempty"`
Id *string `json:"id,omitempty"`
KeyPairId *int `json:"keyPairId"`
Url *string `json:"url,omitempty"`
}
AcmeCertificateRequestView - A reference to a Key Pair to be signed by the ACME protocol.
type AcmeServerView ¶
type AcmeServerView struct {
AcmeAccounts []*LinkView `json:"acmeAccounts,omitempty"`
Id *string `json:"id,omitempty"`
Name *string `json:"name"`
Url *string `json:"url"`
}
AcmeServerView - An ACME server.
type AcmeServersView ¶
type AcmeServersView struct {
Items []*AcmeServerView `json:"items"`
}
AcmeServersView - A collection of ACME servers.
type AdminBasicWebSessionView ¶
type AdminBasicWebSessionView struct {
Audience *string `json:"audience"`
CookieDomain *string `json:"cookieDomain,omitempty"`
CookieType *string `json:"cookieType"`
ExpirationWarningInMinutes *int `json:"expirationWarningInMinutes"`
IdleTimeoutInMinutes *int `json:"idleTimeoutInMinutes"`
SessionPollIntervalInSeconds *int `json:"sessionPollIntervalInSeconds"`
SessionTimeoutInMinutes *int `json:"sessionTimeoutInMinutes"`
}
AdminBasicWebSessionView - An admin basic web session.
type AdminConfigurationView ¶
type AdminConfigurationView struct {
HostPort *string `json:"hostPort"`
HttpProxyId *int `json:"httpProxyId,omitempty"`
HttpsProxyId *int `json:"httpsProxyId,omitempty"`
}
AdminConfigurationView - An admin configuration.
type AdminTokenProviderView ¶
type AdminTokenProviderView struct {
Description *string `json:"description,omitempty"`
Issuer *string `json:"issuer"`
SslCiphers *[]*string `json:"sslCiphers"`
SslProtocols *[]*string `json:"sslProtocols"`
TrustedCertificateGroupId *int `json:"trustedCertificateGroupId,omitempty"`
UseProxy *bool `json:"useProxy,omitempty"`
}
AdminTokenProviderView - An Admin Token Provider.
type AdminWebSessionOidcConfigurationView ¶
type AdminWebSessionOidcConfigurationView struct {
CacheUserAttributes *bool `json:"cacheUserAttributes,omitempty"`
ClientCredentials *OAuthClientCredentialsView `json:"clientCredentials"`
EnableRefreshUser *bool `json:"enableRefreshUser,omitempty"`
OidcLoginType *string `json:"oidcLoginType,omitempty"`
PfsessionStateCacheInSeconds *int `json:"pfsessionStateCacheInSeconds,omitempty"`
PkceChallengeType *string `json:"pkceChallengeType,omitempty"`
RefreshUserInfoClaimsInterval *int `json:"refreshUserInfoClaimsInterval,omitempty"`
Scopes *[]*string `json:"scopes,omitempty"`
SendRequestedUrlToProvider *bool `json:"sendRequestedUrlToProvider,omitempty"`
ValidateSessionIsAlive *bool `json:"validateSessionIsAlive,omitempty"`
}
AdminWebSessionOidcConfigurationView - An admin web session OIDC configuration.
type AgentCertificateView ¶
type AgentCertificateView struct {
Alias *string `json:"alias"`
ChainCertificate *bool `json:"chainCertificate"`
Expires *int `json:"expires,omitempty"`
Id *int `json:"id,omitempty"`
IssuerDn *string `json:"issuerDn"`
KeyPair *bool `json:"keyPair"`
Md5sum *string `json:"md5sum"`
SerialNumber *string `json:"serialNumber"`
Sha1sum *string `json:"sha1sum"`
SignatureAlgorithm *string `json:"signatureAlgorithm"`
Status *string `json:"status"`
SubjectAlternativeNames []*GeneralName `json:"subjectAlternativeNames,omitempty"`
SubjectCn *string `json:"subjectCn,omitempty"`
SubjectDn *string `json:"subjectDn"`
TrustedCertificate *bool `json:"trustedCertificate"`
ValidFrom *int `json:"validFrom,omitempty"`
}
AgentCertificateView - An agent certificate.
type AgentCertificatesView ¶
type AgentCertificatesView struct {
Items []*AgentCertificateView `json:"items"`
}
AgentCertificatesView - A collection of agent certificates.
type AgentView ¶
type AgentView struct {
CertificateHash *Hash `json:"certificateHash,omitempty"`
Description *string `json:"description,omitempty"`
FailedRetryTimeout *int `json:"failedRetryTimeout,omitempty"`
FailoverHosts *[]*string `json:"failoverHosts,omitempty"`
Hostname *string `json:"hostname"`
Id json.Number `json:"id,omitempty"`
IpSource *IpMultiValueSourceView `json:"ipSource,omitempty"`
MaxRetries *int `json:"maxRetries,omitempty"`
Name *string `json:"name"`
OverrideIpSource *bool `json:"overrideIpSource,omitempty"`
Port *int `json:"port"`
SelectedCertificateId *int `json:"selectedCertificateId,omitempty"`
UnknownResourceMode *string `json:"unknownResourceMode,omitempty"`
}
AgentView - An agent.
type AgentsView ¶
type AgentsView struct {
Items []*AgentView `json:"items"`
}
AgentsView - A collection of agents.
type AlgorithmView ¶
AlgorithmView - An algorithm.
type AlgorithmsView ¶
type AlgorithmsView struct {
Items []*AlgorithmView `json:"items"`
}
AlgorithmsView - A collection of valid web session encryption algorithms.
type ApiErrorView ¶
type ApiErrorView struct {
Flash *[]*string `json:"flash"`
Form map[string]*[]*string `json:"form"`
}
ApiErrorView - An API error used by the PingAccess Administrative UI.
type ApplicationView ¶
type ApplicationView struct {
AccessValidatorId *int `json:"accessValidatorId,omitempty"`
AgentCacheInvalidatedExpiration *int `json:"agentCacheInvalidatedExpiration,omitempty"`
AgentCacheInvalidatedResponseDuration *int `json:"agentCacheInvalidatedResponseDuration,omitempty"`
AgentId *int `json:"agentId"`
AllowEmptyPathSegments *bool `json:"allowEmptyPathSegments,omitempty"`
ApplicationType *string `json:"applicationType,omitempty"`
AuthenticationChallengePolicyId *string `json:"authenticationChallengePolicyId"`
CaseSensitivePath *bool `json:"caseSensitivePath,omitempty"`
ContextRoot *string `json:"contextRoot"`
DefaultAuthType *string `json:"defaultAuthType"`
Description *string `json:"description,omitempty"`
Destination *string `json:"destination,omitempty"`
Enabled *bool `json:"enabled,omitempty"`
Id json.Number `json:"id,omitempty"`
IdentityMappingIds map[string]*int `json:"identityMappingIds,omitempty"`
Issuer *string `json:"issuer,omitempty"`
LastModified *int `json:"lastModified,omitempty"`
ManualOrderingEnabled *bool `json:"manualOrderingEnabled,omitempty"`
Name *string `json:"name"`
Policy map[string]*[]*PolicyItem `json:"policy,omitempty"`
Realm *string `json:"realm,omitempty"`
RequireHTTPS *bool `json:"requireHTTPS,omitempty"`
ResourceOrder *[]*int `json:"resourceOrder,omitempty"`
SiteId *int `json:"siteId"`
SpaSupportEnabled *bool `json:"spaSupportEnabled"`
VirtualHostIds *[]*int `json:"virtualHostIds"`
WebSessionId *int `json:"webSessionId,omitempty"`
}
ApplicationView - An application.
type ApplicationsView ¶
type ApplicationsView struct {
Items []*ApplicationView `json:"items"`
}
ApplicationsView - A collection of applications.
type AttributeView ¶
type AttributeView struct {
AttributeName *string `json:"attributeName"`
AttributeValue *string `json:"attributeValue"`
}
AttributeView - A name-value pair of user attributes.
type AuthTokenManagementView ¶
type AuthTokenManagementView struct {
Issuer *string `json:"issuer,omitempty"`
KeyRollEnabled *bool `json:"keyRollEnabled,omitempty"`
KeyRollPeriodInHours *int `json:"keyRollPeriodInHours,omitempty"`
SigningAlgorithm *string `json:"signingAlgorithm,omitempty"`
}
AuthTokenManagementView - An auth token management configuration.
type AuthenticationChallengePoliciesView ¶
type AuthenticationChallengePoliciesView struct {
Items []*AuthenticationChallengePolicyView `json:"items"`
}
AuthenticationChallengePoliciesView - A collection of authentication challenge policies.
type AuthenticationChallengePolicyView ¶
type AuthenticationChallengePolicyView struct {
ChallengeResponseChain []*ChallengeResponseMappingView `json:"challengeResponseChain"`
DefaultChallengeResponse *ChallengeResponseView `json:"defaultChallengeResponse"`
Description *string `json:"description,omitempty"`
Id *string `json:"id,omitempty"`
Name *string `json:"name"`
System *bool `json:"system,omitempty"`
}
AuthenticationChallengePolicyView - An authentication challenge policy.
type AuthnReqListView ¶
type AuthnReqListView struct {
AuthnReqs *[]*string `json:"authnReqs"`
Id json.Number `json:"id,omitempty"`
Name *string `json:"name"`
}
AuthnReqListView - An authentication requirements list.
type AuthnReqListsView ¶
type AuthnReqListsView struct {
Items []*AuthnReqListView `json:"items"`
}
AuthnReqListsView - A collection of authentication requirements lists.
type AuthorizationServerView ¶
type AuthorizationServerView struct {
AuditLevel *string `json:"auditLevel,omitempty"`
CacheTokens *bool `json:"cacheTokens,omitempty"`
ClientCredentials *OAuthClientCredentialsView `json:"clientCredentials,omitempty"`
Description *string `json:"description,omitempty"`
IntrospectionEndpoint *string `json:"introspectionEndpoint"`
Secure *bool `json:"secure,omitempty"`
SendAudience *bool `json:"sendAudience,omitempty"`
SubjectAttributeName *string `json:"subjectAttributeName"`
Targets *[]*string `json:"targets"`
TokenTimeToLiveSeconds *int `json:"tokenTimeToLiveSeconds,omitempty"`
TrustedCertificateGroupId *int `json:"trustedCertificateGroupId"`
UseProxy *bool `json:"useProxy,omitempty"`
}
AuthorizationServerView - The third-party OAuth 2.0 Authorization Server configuration.
type AvailabilityProfileView ¶
type AvailabilityProfileView struct {
ClassName *string `json:"className"`
Configuration map[string]interface{} `json:"configuration"`
Id json.Number `json:"id,omitempty"`
Name *string `json:"name"`
}
AvailabilityProfileView - An availability profile.
type AvailabilityProfilesView ¶
type AvailabilityProfilesView struct {
Items []*AvailabilityProfileView `json:"items"`
}
AvailabilityProfilesView - A collection of availability profiles.
type BasicAuthConfigView ¶
type BasicAuthConfigView struct {
Enabled *bool `json:"enabled,omitempty"`
}
BasicAuthConfigView - A basic authentication configuration.
type BasicConfig ¶
type BasicConfig struct {
Enabled *bool `json:"enabled"`
}
BasicConfig - A basic authentication configuration.
type CSRResponseImportDocView ¶
type CSRResponseImportDocView struct {
ChainCertificates *[]*string `json:"chainCertificates"`
FileData *string `json:"fileData"`
HsmProviderId *int `json:"hsmProviderId"`
TrustedCertGroupId *int `json:"trustedCertGroupId"`
}
CSRResponseImportDocView - A CSR response.
type ChainCertificateView ¶
type ChainCertificateView struct {
Alias *string `json:"alias"`
Expires *int `json:"expires,omitempty"`
Id *int `json:"id,omitempty"`
IssuerDn *string `json:"issuerDn"`
Md5sum *string `json:"md5sum"`
SerialNumber *string `json:"serialNumber"`
Sha1sum *string `json:"sha1sum"`
SignatureAlgorithm *string `json:"signatureAlgorithm"`
Status *string `json:"status"`
SubjectAlternativeNames []*GeneralName `json:"subjectAlternativeNames,omitempty"`
SubjectCn *string `json:"subjectCn,omitempty"`
SubjectDn *string `json:"subjectDn"`
ValidFrom *int `json:"validFrom,omitempty"`
}
ChainCertificateView - A chain certificate.
type ChainCertificatesDocView ¶
type ChainCertificatesDocView struct {
AddChainCertificates *[]*string `json:"addChainCertificates"`
}
ChainCertificatesDocView
type ChallengeResponseFilterView ¶
type ChallengeResponseFilterView struct {
ClassName *string `json:"className"`
Configuration map[string]interface{} `json:"configuration"`
}
ChallengeResponseFilterView - An authentication challenge response filter.
type ChallengeResponseGeneratorView ¶
type ChallengeResponseGeneratorView struct {
ClassName *string `json:"className"`
Configuration map[string]interface{} `json:"configuration"`
}
ChallengeResponseGeneratorView - An authentication challenge response generator.
type ChallengeResponseMappingView ¶
type ChallengeResponseMappingView struct {
ChallengeResponse *ChallengeResponseView `json:"challengeResponse"`
RequestMatcher *RequestMatcherView `json:"requestMatcher"`
}
ChallengeResponseMappingView - A mapping from an unauthenticated request to an authentication challenge response.
type ChallengeResponseView ¶
type ChallengeResponseView struct {
Filter *ChallengeResponseFilterView `json:"filter,omitempty"`
Generator *ChallengeResponseGeneratorView `json:"generator"`
}
ChallengeResponseView - An authentication challenge response.
type ConfigStatusView ¶
type ConfigStatusView struct {
ApiErrorView *ApiErrorView `json:"apiErrorView,omitempty"`
CurrentEntity map[string]interface{} `json:"currentEntity,omitempty"`
Id *int `json:"id,omitempty"`
Status *string `json:"status,omitempty"`
TotalEntities *int `json:"totalEntities,omitempty"`
Warnings *[]*string `json:"warnings"`
}
ConfigStatusView - An import or export configuration.
type ConfigStatusesView ¶
type ConfigStatusesView struct {
Items []*ConfigStatusView `json:"items"`
}
ConfigStatusesView - A collection of import or export configuration workflows.
type ConfigurationDependentFieldOption ¶
type ConfigurationDependentFieldOption struct {
Options []*ConfigurationOption `json:"options"`
Value *string `json:"value"`
}
ConfigurationDependentFieldOption - Configuration of the dependent field option.
type ConfigurationField ¶
type ConfigurationField struct {
Advanced *bool `json:"advanced"`
ButtonGroup *string `json:"buttonGroup"`
Default *string `json:"default"`
Deselectable *bool `json:"deselectable"`
Fields []*ConfigurationField `json:"fields"`
Help *Help `json:"help"`
Label *string `json:"label"`
Name *string `json:"name"`
Options []*ConfigurationOption `json:"options"`
ParentField *ConfigurationParentField `json:"parentField"`
Required *bool `json:"required"`
Type *string `json:"type"`
}
ConfigurationField - Details for configuration in the administrator console.
type ConfigurationOption ¶
type ConfigurationOption struct {
Category *string `json:"category"`
Label *string `json:"label"`
Value *string `json:"value"`
}
ConfigurationOption - The configuration option attributes.
type ConfigurationParentField ¶
type ConfigurationParentField struct {
DependentFieldOptions []*ConfigurationDependentFieldOption `json:"dependentFieldOptions"`
FieldName *string `json:"fieldName"`
}
ConfigurationParentField - Configuration of the parent field.
type CookieTypesView ¶
type CookieTypesView struct {
Items []*ItemView `json:"items"`
}
CookieTypesView - A collection of valid values for the web session cookie type.
type DescriptorView ¶
type DescriptorView struct {
ClassName *string `json:"className"`
ConfigurationFields []*ConfigurationField `json:"configurationFields"`
Label *string `json:"label"`
Type *string `json:"type"`
}
DescriptorView - A descriptor.
type DescriptorsView ¶
type DescriptorsView struct {
Items []*DescriptorView `json:"items"`
}
DescriptorsView - A list of descriptors.
type EmbeddableAccessTokenValidatorView ¶
type EmbeddableAccessTokenValidatorView struct {
ClassName *string `json:"className"`
Configuration map[string]interface{} `json:"configuration"`
}
EmbeddableAccessTokenValidatorView - An Embeddable Access Token Validator configuration.
type EngineCertificateView ¶
type EngineCertificateView struct {
Alias *string `json:"alias"`
ChainCertificate *bool `json:"chainCertificate"`
Expires *int `json:"expires,omitempty"`
Id *int `json:"id,omitempty"`
IssuerDn *string `json:"issuerDn"`
KeyPair *bool `json:"keyPair"`
Md5sum *string `json:"md5sum"`
SerialNumber *string `json:"serialNumber"`
Sha1sum *string `json:"sha1sum"`
SignatureAlgorithm *string `json:"signatureAlgorithm"`
Status *string `json:"status"`
SubjectAlternativeNames []*GeneralName `json:"subjectAlternativeNames,omitempty"`
SubjectCn *string `json:"subjectCn,omitempty"`
SubjectDn *string `json:"subjectDn"`
TrustedCertificate *bool `json:"trustedCertificate"`
ValidFrom *int `json:"validFrom,omitempty"`
}
EngineCertificateView - An engine certificate.
type EngineHealthStatusView ¶
type EngineHealthStatusView struct {
CurrentServerTime *int `json:"currentServerTime"`
EnginesStatus map[string]*EngineInfo `json:"enginesStatus"`
}
EngineHealthStatusView
type EngineInfo ¶
type EngineInfo struct {
Description *string `json:"description"`
LastUpdated *int `json:"lastUpdated"`
Name *string `json:"name"`
PollingDelay *int `json:"pollingDelay"`
}
EngineInfo
type EngineListenerView ¶
type EngineListenerView struct {
Id json.Number `json:"id,omitempty"`
Name *string `json:"name"`
Port *int `json:"port"`
Secure *bool `json:"secure,omitempty"`
TrustedCertificateGroupId *int `json:"trustedCertificateGroupId,omitempty"`
}
EngineListenerView - An engine listener.
type EngineListenersView ¶
type EngineListenersView struct {
Items []*EngineListenerView `json:"items"`
}
EngineListenersView - A collection of engine listeners.
type EngineView ¶
type EngineView struct {
CertificateHash *Hash `json:"certificateHash,omitempty"`
ConfigReplicationEnabled *bool `json:"configReplicationEnabled,omitempty"`
Description *string `json:"description,omitempty"`
HttpProxyId *int `json:"httpProxyId,omitempty"`
HttpsProxyId *int `json:"httpsProxyId,omitempty"`
Id json.Number `json:"id,omitempty"`
Keys []*PublicKeyView `json:"keys,omitempty"`
Name *string `json:"name"`
SelectedCertificateId *int `json:"selectedCertificateId,omitempty"`
}
EngineView - An engine.
type EnginesView ¶
type EnginesView struct {
Items []*EngineView `json:"items"`
}
EnginesView - A collection of engines.
type EnvironmentView ¶
type EnvironmentView struct {
Name *string `json:"name"`
}
EnvironmentView - An Environment.
type ExportData ¶
type ExportData struct {
Data map[string]interface{} `json:"data"`
EncryptionKey *JsonWebKey `json:"encryptionKey"`
Id json.Number `json:"id,omitempty"`
MasterKeys *MasterKeysView `json:"masterKeys"`
Version *string `json:"version"`
}
ExportData - A JSON backup file.
type ExportParameters ¶
type ExportParameters struct {
HsmProviderId *int `json:"hsmProviderId"`
Id *int `json:"id"`
Password *HiddenFieldView `json:"password"`
}
ExportParameters - The export parameters for a key pair.
type GeneralName ¶
GeneralName - A subject alternative name.
type GlobalUnprotectedResourceView ¶
type GlobalUnprotectedResourceView struct {
AuditLevel *string `json:"auditLevel,omitempty"`
Description *string `json:"description,omitempty"`
Enabled *bool `json:"enabled,omitempty"`
Id json.Number `json:"id,omitempty"`
Name *string `json:"name"`
WildcardPath *string `json:"wildcardPath"`
}
GlobalUnprotectedResourceView - A global unprotected resource.
type GlobalUnprotectedResourcesView ¶
type GlobalUnprotectedResourcesView struct {
Items []*GlobalUnprotectedResourceView `json:"items"`
}
GlobalUnprotectedResourcesView - A collection of global unprotected resource items.
type Help ¶
type Help struct {
Content *string `json:"content"`
Title *string `json:"title"`
Url *string `json:"url"`
}
Help - Configuration of the help context of a configuration field.
type HiddenFieldView ¶
type HiddenFieldView struct {
EncryptedValue *string `json:"encryptedValue,omitempty"`
Value *string `json:"value,omitempty"`
}
HiddenFieldView - A hidden field.
type HostMultiValueSourceView ¶
type HostMultiValueSourceView struct {
HeaderNameList *[]*string `json:"headerNameList"`
ListValueLocation *string `json:"listValueLocation"`
}
HostMultiValueSourceView - Configuration for the host source.
type HostPortView ¶
HostPortView - A redirect source.
type HsmProviderView ¶
type HsmProviderView struct {
ClassName *string `json:"className"`
Configuration map[string]interface{} `json:"configuration"`
Id json.Number `json:"id,omitempty"`
Name *string `json:"name"`
}
HsmProviderView - An HSM provider.
type HttpClientProxyView ¶
type HttpClientProxyView struct {
Description *string `json:"description,omitempty"`
Host *string `json:"host"`
Id json.Number `json:"id,omitempty"`
Name *string `json:"name"`
Password *HiddenFieldView `json:"password,omitempty"`
Port *int `json:"port"`
RequiresAuthentication *bool `json:"requiresAuthentication,omitempty"`
Username *string `json:"username,omitempty"`
}
HttpClientProxyView - A proxy.
type HttpMonitoringView ¶
type HttpMonitoringView struct {
AuditLevel *string `json:"auditLevel,omitempty"`
}
HttpMonitoringView
type HttpsListenerView ¶
type HttpsListenerView struct {
Id json.Number `json:"id,omitempty"`
KeyPairId *int `json:"keyPairId"`
Name *string `json:"name"`
RestartRequired *bool `json:"restartRequired"`
UseServerCipherSuiteOrder *bool `json:"useServerCipherSuiteOrder"`
}
HttpsListenerView - An HTTPS listener.
type HttpsListenersView ¶
type HttpsListenersView struct {
Items []*HttpsListenerView `json:"items"`
}
HttpsListenersView - A collection of HTTPS listeners.
type IdentityMappingView ¶
type IdentityMappingView struct {
ClassName *string `json:"className"`
Configuration map[string]interface{} `json:"configuration"`
Id json.Number `json:"id,omitempty"`
Name *string `json:"name"`
}
IdentityMappingView - An identity mapping.
type IdentityMappingsView ¶
type IdentityMappingsView struct {
Items []*IdentityMappingView `json:"items"`
}
IdentityMappingsView - A collection of identity mappings.
type IpMultiValueSourceView ¶
type IpMultiValueSourceView struct {
FallbackToLastHopIp *bool `json:"fallbackToLastHopIp,omitempty"`
HeaderNameList *[]*string `json:"headerNameList"`
ListValueLocation *string `json:"listValueLocation"`
}
IpMultiValueSourceView - Configuration for the IP source.
type JsonWebKey ¶
type JsonWebKey struct {
Algorithm *string `json:"algorithm"`
Key *Key `json:"key"`
KeyId *string `json:"keyId"`
KeyOps *[]*string `json:"keyOps"`
KeyType *string `json:"keyType"`
PublicKey *PublicKey `json:"publicKey"`
Use *string `json:"use"`
}
JsonWebKey - A JSON Web Key.
type Key ¶
type Key struct {
Algorithm *string `json:"algorithm"`
Encoded *[]*byte `json:"encoded"`
Format *string `json:"format"`
}
Key - A key.
type KeyAlgorithm ¶
type KeyAlgorithm struct {
DefaultKeySize *int `json:"defaultKeySize"`
DefaultSignatureAlgorithm *string `json:"defaultSignatureAlgorithm"`
KeySizes *[]*int `json:"keySizes"`
Name *string `json:"name"`
SignatureAlgorithms *[]*string `json:"signatureAlgorithms"`
}
KeyAlgorithm - A key algorithm.
type KeyAlgorithmsView ¶
type KeyAlgorithmsView struct {
Items []*KeyAlgorithm `json:"items"`
}
KeyAlgorithmsView - A collection of key algorithms.
type KeyPairView ¶
type KeyPairView struct {
Alias *string `json:"alias"`
ChainCertificates []*ChainCertificateView `json:"chainCertificates,omitempty"`
CsrPending *bool `json:"csrPending"`
Expires *int `json:"expires,omitempty"`
HsmProviderId *int `json:"hsmProviderId,omitempty"`
Id *int `json:"id,omitempty"`
IssuerDn *string `json:"issuerDn"`
Md5sum *string `json:"md5sum"`
SerialNumber *string `json:"serialNumber"`
Sha1sum *string `json:"sha1sum"`
SignatureAlgorithm *string `json:"signatureAlgorithm"`
Status *string `json:"status"`
SubjectAlternativeNames []*GeneralName `json:"subjectAlternativeNames,omitempty"`
SubjectCn *string `json:"subjectCn,omitempty"`
SubjectDn *string `json:"subjectDn"`
ValidFrom *int `json:"validFrom,omitempty"`
}
KeyPairView - A key pair.
type KeyPairsView ¶
type KeyPairsView struct {
Items []*KeyPairView `json:"items"`
}
KeyPairsView - A collection of key pairs.
type KeySetView ¶
KeySetView - An auth token key set configuration.
type LicenseImportDocView ¶
type LicenseImportDocView struct {
FileData *string `json:"fileData"`
}
LicenseImportDocView - A license file.
type LicenseView ¶
type LicenseView struct {
EnforcementType *int `json:"enforcementType"`
ExpirationDate *string `json:"expirationDate"`
Id *int `json:"id"`
IssueDate *string `json:"issueDate"`
MaxApplications *int `json:"maxApplications"`
Name *string `json:"name"`
Organization *string `json:"organization"`
Product *string `json:"product"`
Tier *string `json:"tier"`
Version *string `json:"version"`
}
LicenseView - A Ping Identity license.
type LoadBalancingStrategiesView ¶
type LoadBalancingStrategiesView struct {
Items []*LoadBalancingStrategyView `json:"items"`
}
LoadBalancingStrategiesView - A collection of load balancing strategies.
type LoadBalancingStrategyView ¶
type LoadBalancingStrategyView struct {
ClassName *string `json:"className"`
Configuration map[string]interface{} `json:"configuration"`
Id json.Number `json:"id,omitempty"`
Name *string `json:"name"`
}
LoadBalancingStrategyView - A load balancing strategy.
type MasterKeysView ¶
type MasterKeysView struct {
EncryptedValue *[]*byte `json:"encryptedValue"`
KeyId *string `json:"keyId"`
}
MasterKeysView - An encrypted master key.
type NewKeyPairConfigView ¶
type NewKeyPairConfigView struct {
Alias *string `json:"alias"`
City *string `json:"city"`
CommonName *string `json:"commonName"`
Country *string `json:"country"`
HsmProviderId *int `json:"hsmProviderId"`
Id *int `json:"id,omitempty"`
KeyAlgorithm *string `json:"keyAlgorithm"`
KeySize *int `json:"keySize"`
Organization *string `json:"organization"`
OrganizationUnit *string `json:"organizationUnit"`
SignatureAlgorithm *string `json:"signatureAlgorithm,omitempty"`
State *string `json:"state"`
SubjectAlternativeNames []*GeneralName `json:"subjectAlternativeNames,omitempty"`
ValidDays *int `json:"validDays"`
}
NewKeyPairConfigView - A new key pair.
type OAuthClientCredentialsView ¶
type OAuthClientCredentialsView struct {
ClientId *string `json:"clientId"`
ClientSecret *HiddenFieldView `json:"clientSecret,omitempty"`
CredentialsType *string `json:"credentialsType,omitempty"`
KeyPairId *int `json:"keyPairId,omitempty"`
}
OAuthClientCredentialsView - OAuth client credentials.
type OAuthConfigView ¶
type OAuthConfigView struct {
AccessTokenValidator *EmbeddableAccessTokenValidatorView `json:"accessTokenValidator,omitempty"`
ClientCredentials *OAuthClientCredentialsView `json:"clientCredentials,omitempty"`
ClientId *string `json:"clientId,omitempty"`
ClientSecret *HiddenFieldView `json:"clientSecret,omitempty"`
Enabled *bool `json:"enabled,omitempty"`
RoleMapping *RoleMappingConfigurationView `json:"roleMapping,omitempty"`
Scope *string `json:"scope"`
SubjectAttributeName *string `json:"subjectAttributeName,omitempty"`
}
OAuthConfigView - An OAuth authentication configuration.
type OAuthKeyManagementView ¶
type OAuthKeyManagementView struct {
KeyRollEnabled *bool `json:"keyRollEnabled,omitempty"`
KeyRollPeriodInHours *int `json:"keyRollPeriodInHours,omitempty"`
SigningAlgorithm *string `json:"signingAlgorithm,omitempty"`
}
OAuthKeyManagementView - An OAuth key management configuration.
type OIDCProviderMetadata ¶
type OIDCProviderMetadata struct {
AuthorizationEndpoint *string `json:"authorization_endpoint"`
BackchannelAuthenticationEndpoint *string `json:"backchannel_authentication_endpoint"`
ClaimTypesSupported *[]*string `json:"claim_types_supported"`
ClaimsParameterSupported *bool `json:"claims_parameter_supported"`
ClaimsSupported *[]*string `json:"claims_supported"`
CodeChallengeMethodsSupported *[]*string `json:"code_challenge_methods_supported"`
EndSessionEndpoint *string `json:"end_session_endpoint"`
GrantTypesSupported *[]*string `json:"grant_types_supported"`
IdTokenSigningAlgValuesSupported *[]*string `json:"id_token_signing_alg_values_supported"`
IntrospectionEndpoint *string `json:"introspection_endpoint"`
Issuer *string `json:"issuer"`
JwksUri *string `json:"jwks_uri"`
MtlsEndpointAliases map[string]*string `json:"mtls_endpoint_aliases"`
PingEndSessionEndpoint *string `json:"ping_end_session_endpoint"`
PingRevokedSrisEndpoint *string `json:"ping_revoked_sris_endpoint"`
RequestObjectSigningAlgValuesSupported *[]*string `json:"request_object_signing_alg_values_supported"`
RequestParameterSupported *bool `json:"request_parameter_supported"`
RequestUriParameterSupported *bool `json:"request_uri_parameter_supported"`
ResponseModesSupported *[]*string `json:"response_modes_supported"`
ResponseTypesSupported *[]*string `json:"response_types_supported"`
RevocationEndpoint *string `json:"revocation_endpoint"`
ScopesSupported *[]*string `json:"scopes_supported"`
SubjectTypesSupported *[]*string `json:"subject_types_supported"`
TokenEndpoint *string `json:"token_endpoint"`
TokenEndpointAuthMethodsSupported *[]*string `json:"token_endpoint_auth_methods_supported"`
TokenEndpointAuthSigningAlgValuesSupported *[]*string `json:"token_endpoint_auth_signing_alg_values_supported"`
UserinfoEndpoint *string `json:"userinfo_endpoint"`
UserinfoSigningAlgValuesSupported *[]*string `json:"userinfo_signing_alg_values_supported"`
}
OIDCProviderMetadata - The OpenID Connect provider's metadata.
type OIDCProviderPluginView ¶
type OIDCProviderPluginView struct {
ClassName *string `json:"className"`
Configuration map[string]interface{} `json:"configuration"`
}
OIDCProviderPluginView - An OpenID Connect provider plugin.
type OIDCProviderView ¶
type OIDCProviderView struct {
AuditLevel *string `json:"auditLevel,omitempty"`
Description *string `json:"description,omitempty"`
Issuer *string `json:"issuer"`
Plugin *OIDCProviderPluginView `json:"plugin,omitempty"`
QueryParameters []*QueryParameterView `json:"queryParameters,omitempty"`
RequestSupportedScopesOnly *bool `json:"requestSupportedScopesOnly,omitempty"`
TrustedCertificateGroupId *int `json:"trustedCertificateGroupId,omitempty"`
UseProxy *bool `json:"useProxy,omitempty"`
UseSlo *bool `json:"useSlo,omitempty"`
}
OIDCProviderView - The third-party OpenID Connect provider configuration.
type OidcConfigView ¶
type OidcConfigView struct {
AuthnReqListId *int `json:"authnReqListId,omitempty"`
Enabled *bool `json:"enabled,omitempty"`
OidcConfiguration *AdminWebSessionOidcConfigurationView `json:"oidcConfiguration"`
RoleMapping *RoleMappingConfigurationView `json:"roleMapping,omitempty"`
UseSlo *bool `json:"useSlo,omitempty"`
UsernameAttributeName *string `json:"usernameAttributeName,omitempty"`
}
OidcConfigView - An OIDC authentication configuration.
type OidcLoginTypesView ¶
type OidcLoginTypesView struct {
Items []*ItemView `json:"items"`
}
OidcLoginTypesView - A collection of valid web session OIDC login types.
type OptionalAttributeMappingView ¶
type OptionalAttributeMappingView struct {
Attributes []*AttributeView `json:"attributes"`
Enabled *bool `json:"enabled,omitempty"`
}
OptionalAttributeMappingView - A set of user attributes that define an optional role mapping.
type PKCS12FileImportDocView ¶
type PKCS12FileImportDocView struct {
Alias *string `json:"alias"`
ChainCertificates *[]*string `json:"chainCertificates"`
FileData *string `json:"fileData"`
HsmProviderId *int `json:"hsmProviderId"`
Password *HiddenFieldView `json:"password"`
}
PKCS12FileImportDocView - A PKCS#12 file.
type PathPatternView ¶
PathPatternView - A pattern for matching request URI paths.
type PingFederateAccessTokenView ¶
type PingFederateAccessTokenView struct {
AccessValidatorId *int `json:"accessValidatorId"`
CacheTokens *bool `json:"cacheTokens,omitempty"`
ClientCredentials *OAuthClientCredentialsView `json:"clientCredentials,omitempty"`
ClientId *string `json:"clientId,omitempty"`
ClientSecret *HiddenFieldView `json:"clientSecret,omitempty"`
Name *string `json:"name,omitempty"`
SendAudience *bool `json:"sendAudience,omitempty"`
SubjectAttributeName *string `json:"subjectAttributeName"`
TokenTimeToLiveSeconds *int `json:"tokenTimeToLiveSeconds,omitempty"`
UseTokenIntrospection *bool `json:"useTokenIntrospection,omitempty"`
}
PingFederateAccessTokenView - A PingAccess OAuth client configuration.
type PingFederateAdminView ¶
type PingFederateAdminView struct {
AdminPassword *HiddenFieldView `json:"adminPassword"`
AdminUsername *string `json:"adminUsername"`
AuditLevel *string `json:"auditLevel,omitempty"`
BasePath *string `json:"basePath,omitempty"`
Host *string `json:"host"`
Port *int `json:"port"`
Secure *bool `json:"secure,omitempty"`
TrustedCertificateGroupId *int `json:"trustedCertificateGroupId,omitempty"`
UseProxy *bool `json:"useProxy,omitempty"`
}
PingFederateAdminView - A PingFederate Admin configuration.
type PingFederateMetadataRuntimeView ¶
type PingFederateMetadataRuntimeView struct {
Description *string `json:"description,omitempty"`
Issuer *string `json:"issuer"`
SkipHostnameVerification *bool `json:"skipHostnameVerification,omitempty"`
StsTokenExchangeEndpoint *string `json:"stsTokenExchangeEndpoint,omitempty"`
TrustedCertificateGroupId *int `json:"trustedCertificateGroupId,omitempty"`
UseProxy *bool `json:"useProxy,omitempty"`
UseSlo *bool `json:"useSlo,omitempty"`
}
PingFederateMetadataRuntimeView - A PingFederate configuration.
type PingFederateRuntimeApplicationView ¶
type PingFederateRuntimeApplicationView struct {
AdditionalVirtualHostIds *[]*int `json:"additionalVirtualHostIds,omitempty"`
CaseSensitive *bool `json:"caseSensitive,omitempty"`
ClientCertHeaderNames *[]*string `json:"clientCertHeaderNames,omitempty"`
ContextRoot *string `json:"contextRoot,omitempty"`
Policy []*PolicyItem `json:"policy,omitempty"`
PrimaryVirtualHostId *int `json:"primaryVirtualHostId"`
}
PingFederateRuntimeApplicationView - Configuration required to help define application data to handle PingFederate as both a token provider and a proxied application.
type PingFederateRuntimeView ¶
type PingFederateRuntimeView struct {
Application *PingFederateRuntimeApplicationView `json:"application,omitempty"`
AuditLevel *string `json:"auditLevel,omitempty"`
AvailabilityProfileId *int `json:"availabilityProfileId,omitempty"`
BackChannelBasePath *string `json:"backChannelBasePath,omitempty"`
BackChannelSecure *bool `json:"backChannelSecure,omitempty"`
BasePath *string `json:"basePath,omitempty"`
ExpectedHostname *string `json:"expectedHostname,omitempty"`
Host *string `json:"host"`
LoadBalancingStrategyId *int `json:"loadBalancingStrategyId,omitempty"`
Port *int `json:"port"`
Secure *bool `json:"secure,omitempty"`
SkipHostnameVerification *bool `json:"skipHostnameVerification,omitempty"`
Targets *[]*string `json:"targets,omitempty"`
TrustedCertificateGroupId *int `json:"trustedCertificateGroupId,omitempty"`
UseProxy *bool `json:"useProxy,omitempty"`
UseSlo *bool `json:"useSlo,omitempty"`
}
PingFederateRuntimeView - A PingFederate configuration.
type PingOne4CView ¶
type PingOne4CView struct {
Description *string `json:"description,omitempty"`
Issuer *string `json:"issuer"`
TrustedCertificateGroupId *int `json:"trustedCertificateGroupId,omitempty"`
UseProxy *bool `json:"useProxy,omitempty"`
}
PingOne4CView - The PingOne for Customers OIDC provider configuration.
type PolicyItem ¶
type PolicyItem struct {
Id json.Number `json:"id,omitempty"`
Type *string `json:"type,omitempty"`
}
PolicyItem - The policy items associated with the application - Now an undocumented model type
type ProblemDocumentView ¶
ProblemDocumentView - An RFC 7807 problem details object.
type ProtocolSourceView ¶
type ProtocolSourceView struct {
HeaderName *string `json:"headerName"`
}
ProtocolSourceView - Configuration for the protocol source.
type PublicKeyView ¶
type PublicKeyView struct {
Created *time.Time `json:"created,omitempty"`
Jwk map[string]interface{} `json:"jwk"`
}
PublicKeyView - A public key.
type QueryParamConfigView ¶
type QueryParamConfigView struct {
MatchesNoParams *bool `json:"matchesNoParams"`
Params []*QueryParamPairView `json:"params"`
}
QueryParamConfigView - Query parameter configuration settings to match requests to URLs with query parameters.
type QueryParamNameView ¶
QueryParamNameView
type QueryParamPairView ¶
type QueryParamPairView struct {
Name *QueryParamNameView `json:"name"`
Value *QueryParamValueView `json:"value"`
}
QueryParamPairView
type QueryParamValueView ¶
type QueryParamValueView struct {
MatchAny *bool `json:"matchAny"`
Pattern *string `json:"pattern"`
Type *string `json:"type"`
}
QueryParamValueView
type QueryParameterView ¶
QueryParameterView - A name-value pair of custom query parameters.
type RedirectView ¶
type RedirectView struct {
AuditLevel *string `json:"auditLevel,omitempty"`
Id *string `json:"id,omitempty"`
ResponseCode *int `json:"responseCode,omitempty"`
Source *HostPortView `json:"source,omitempty"`
Target *TargetHostPortView `json:"target,omitempty"`
}
RedirectView - A Redirect.
type RedirectsView ¶
type RedirectsView struct {
Items []*RedirectView `json:"items"`
}
RedirectsView - A collection of Redirects.
type RejectionHandlerView ¶
type RejectionHandlerView struct {
ClassName *string `json:"className"`
Configuration map[string]interface{} `json:"configuration"`
Id json.Number `json:"id,omitempty"`
Name *string `json:"name"`
}
RejectionHandlerView - A rejection handler.
type RejectionHandlersView ¶
type RejectionHandlersView struct {
Items []*RejectionHandlerView `json:"items"`
}
RejectionHandlersView - A collection of rejection handlers.
type ReplicaAdminView ¶
type ReplicaAdminView struct {
CertificateHash *Hash `json:"certificateHash,omitempty"`
ConfigReplicationEnabled *bool `json:"configReplicationEnabled,omitempty"`
Description *string `json:"description,omitempty"`
HostPort *string `json:"hostPort"`
HttpProxyId *int `json:"httpProxyId,omitempty"`
HttpsProxyId *int `json:"httpsProxyId,omitempty"`
Id json.Number `json:"id,omitempty"`
Keys []*PublicKeyView `json:"keys,omitempty"`
Name *string `json:"name"`
SelectedCertificateId *int `json:"selectedCertificateId,omitempty"`
}
ReplicaAdminView - A replica admin.
type ReplicaAdminsView ¶
type ReplicaAdminsView struct {
Items []*ReplicaAdminView `json:"items"`
}
ReplicaAdminsView - A list of replica admins.
type RequestMatcherView ¶
type RequestMatcherView struct {
ClassName *string `json:"className"`
Configuration map[string]interface{} `json:"configuration"`
}
RequestMatcherView - A request matcher used to match an unauthenticated request to its challenge response.
type RequestPreservationTypesView ¶
type RequestPreservationTypesView struct {
Items []*ItemView `json:"items"`
}
RequestPreservationTypesView - A collection of valid web session request preservation types.
type RequiredAttributeMappingView ¶
type RequiredAttributeMappingView struct {
Attributes []*AttributeView `json:"attributes"`
}
RequiredAttributeMappingView - A set of user attributes that define a mandatory role mapping.
type ReservedApplicationView ¶
type ReservedApplicationView struct {
ContextRoot *string `json:"contextRoot"`
}
ReservedApplicationView - The reserved application.
type ResourceMatchingEntryView ¶
type ResourceMatchingEntryView struct {
Link *LinkView `json:"link"`
Methods *[]*string `json:"methods"`
Name *string `json:"name"`
Pattern *string `json:"pattern"`
PatternType *string `json:"patternType"`
Type *string `json:"type"`
}
ResourceMatchingEntryView - A resource matching entry.
type ResourceMatchingEvaluationOrderView ¶
type ResourceMatchingEvaluationOrderView struct {
Entries []*ResourceMatchingEntryView `json:"entries"`
}
ResourceMatchingEvaluationOrderView - Specifies an ordering of Resource Matching Entries.
type ResourceOrderView ¶
type ResourceOrderView struct {
Id json.Number `json:"id,omitempty"`
ResourceIds *[]*int `json:"resourceIds"`
}
ResourceOrderView - Specifies an ordering of Application Resources.
type ResourceTypeConfigurationView ¶
type ResourceTypeConfigurationView struct {
ResponseGenerator *ResponseGeneratorView `json:"responseGenerator,omitempty"`
}
ResourceTypeConfigurationView - A container for configuration specific to various types of resources.
type ResourceView ¶
type ResourceView struct {
Anonymous *bool `json:"anonymous,omitempty"`
ApplicationId *int `json:"applicationId,omitempty"`
AuditLevel *string `json:"auditLevel,omitempty"`
AuthenticationChallengePolicyId *string `json:"authenticationChallengePolicyId"`
DefaultAuthTypeOverride *string `json:"defaultAuthTypeOverride"`
Enabled *bool `json:"enabled,omitempty"`
Id json.Number `json:"id,omitempty"`
Methods *[]*string `json:"methods"`
Name *string `json:"name"`
PathPatterns []*PathPatternView `json:"pathPatterns,omitempty"`
PathPrefixes *[]*string `json:"pathPrefixes,omitempty"`
Policy map[string]*[]*PolicyItem `json:"policy,omitempty"`
QueryParamConfig *QueryParamConfigView `json:"queryParamConfig,omitempty"`
ResourceType *string `json:"resourceType,omitempty"`
ResourceTypeConfiguration *ResourceTypeConfigurationView `json:"resourceTypeConfiguration,omitempty"`
RootResource *bool `json:"rootResource,omitempty"`
Unprotected *bool `json:"unprotected,omitempty"`
}
ResourceView - A resource.
type ResourcesView ¶
type ResourcesView struct {
Items []*ResourceView `json:"items"`
}
ResourcesView - A collection of resources.
type ResponseGeneratorView ¶
type ResponseGeneratorView struct {
ClassName *string `json:"className"`
Configuration map[string]interface{} `json:"configuration"`
}
ResponseGeneratorView
type RevocationCheckingView ¶
type RevocationCheckingView struct {
CrlChecking *bool `json:"crlChecking,omitempty"`
DenyRevocationStatusUnknown *bool `json:"denyRevocationStatusUnknown,omitempty"`
Ocsp *bool `json:"ocsp,omitempty"`
}
RevocationCheckingView - The client certificate revocation checking configuration.
type RoleMappingConfigurationView ¶
type RoleMappingConfigurationView struct {
Administrator *RequiredAttributeMappingView `json:"administrator,omitempty"`
Auditor *OptionalAttributeMappingView `json:"auditor,omitempty"`
Enabled *bool `json:"enabled,omitempty"`
PlatformAdmin *OptionalAttributeMappingView `json:"platformAdmin,omitempty"`
}
RoleMappingConfigurationView - Configuration for mapping user attributes to roles.
type RuleDescriptorView ¶
type RuleDescriptorView struct {
AgentCachingDisabled *bool `json:"agentCachingDisabled"`
Category *string `json:"category"`
ClassName *string `json:"className"`
ConfigurationFields []*ConfigurationField `json:"configurationFields"`
Label *string `json:"label"`
Modes []*string `json:"modes"`
Type *string `json:"type"`
}
RuleDescriptorView - A rule descriptor.
type RuleDescriptorsView ¶
type RuleDescriptorsView struct {
Items []*RuleDescriptorView `json:"items"`
}
RuleDescriptorsView - A collection of rule descriptors.
type RuleSetElementTypesView ¶
type RuleSetElementTypesView struct {
Items []*ItemView `json:"items"`
}
RuleSetElementTypesView - A collection of rule set element types.
type RuleSetSuccessCriteriaView ¶
type RuleSetSuccessCriteriaView struct {
Items []*ItemView `json:"items"`
}
RuleSetSuccessCriteriaView - A collection of success criteria.
type RuleSetView ¶
type RuleSetView struct {
ElementType *string `json:"elementType,omitempty"`
Id json.Number `json:"id,omitempty"`
Name *string `json:"name"`
Policy *[]*int `json:"policy"`
SuccessCriteria *string `json:"successCriteria,omitempty"`
}
RuleSetView - A rule set.
type RuleSetsView ¶
type RuleSetsView struct {
Items []*RuleSetView `json:"items"`
}
RuleSetsView - A collection of rule sets.
type RuleView ¶
type RuleView struct {
ClassName *string `json:"className"`
Configuration map[string]interface{} `json:"configuration"`
Id json.Number `json:"id,omitempty"`
Name *string `json:"name"`
SupportedDestinations *[]*string `json:"supportedDestinations,omitempty"`
}
RuleView - A rule.
type RulesView ¶
type RulesView struct {
Items []*RuleView `json:"items"`
}
RulesView - A collection of rules.
type SanType ¶
type SanType struct {
Description *string `json:"description,omitempty"`
Name *string `json:"name,omitempty"`
}
SanType - An undocumented model type
type SanTypes ¶
type SanTypes struct {
Items *[]*SanType `json:"items"`
}
SanTypes - A collection of available general names.
type SessionInfo ¶
type SessionInfo struct {
AccessControlDirectives *[]*string `json:"accessControlDirectives"`
ConfigurationExports *ConfigStatusesView `json:"configurationExports"`
ConfigurationImports *ConfigStatusesView `json:"configurationImports"`
Exp *int `json:"exp"`
ExpWarn *int `json:"expWarn"`
Flash *string `json:"flash"`
Iat *int `json:"iat"`
MaxFileUploadSize *int `json:"maxFileUploadSize"`
PollIntervalSeconds *int `json:"pollIntervalSeconds"`
Roles *[]*string `json:"roles"`
SesTimeout *int `json:"sesTimeout"`
ShowWarning *bool `json:"showWarning"`
SniEnabled *bool `json:"sniEnabled"`
Sub *string `json:"sub"`
UseSlo *bool `json:"useSlo"`
}
SessionInfo - A session.
type SharedSecretsView ¶
type SharedSecretsView struct {
}
SharedSecretsView - A collection of shared secrets.
type SigningAlgorithmsView ¶
type SigningAlgorithmsView struct {
Items []*AlgorithmView `json:"items"`
}
SigningAlgorithmsView - A collection of valid web session signing algorithms.
type SiteAuthenticatorView ¶
type SiteAuthenticatorView struct {
ClassName *string `json:"className"`
Configuration map[string]interface{} `json:"configuration"`
Id json.Number `json:"id,omitempty"`
Name *string `json:"name"`
}
SiteAuthenticatorView - A site authenticator.
type SiteAuthenticatorsView ¶
type SiteAuthenticatorsView struct {
Items []*SiteAuthenticatorView `json:"items"`
}
SiteAuthenticatorsView - A collection of site authenticators.
type SiteView ¶
type SiteView struct {
AvailabilityProfileId *int `json:"availabilityProfileId,omitempty"`
ExpectedHostname *string `json:"expectedHostname,omitempty"`
Id json.Number `json:"id,omitempty"`
KeepAliveTimeout *int `json:"keepAliveTimeout,omitempty"`
LoadBalancingStrategyId *int `json:"loadBalancingStrategyId,omitempty"`
MaxConnections *int `json:"maxConnections,omitempty"`
MaxWebSocketConnections *int `json:"maxWebSocketConnections,omitempty"`
Name *string `json:"name"`
Secure *bool `json:"secure,omitempty"`
SendPaCookie *bool `json:"sendPaCookie,omitempty"`
SiteAuthenticatorIds *[]*int `json:"siteAuthenticatorIds,omitempty"`
SkipHostnameVerification *bool `json:"skipHostnameVerification,omitempty"`
Targets *[]*string `json:"targets"`
TrustedCertificateGroupId *int `json:"trustedCertificateGroupId,omitempty"`
UseProxy *bool `json:"useProxy,omitempty"`
UseTargetHostHeader *bool `json:"useTargetHostHeader,omitempty"`
}
SiteView - A site.
type SitesView ¶
type SitesView struct {
Items []*SiteView `json:"items"`
}
SitesView - A collection of sites items.
type SupportedScopesView ¶
type SupportedScopesView struct {
ClientId *string `json:"clientId"`
Scopes *[]*string `json:"scopes"`
}
SupportedScopesView - A set of scopes supported by the OIDC Provider.
type TargetHostPortView ¶
type TargetHostPortView struct {
Host *string `json:"host"`
Port *int `json:"port"`
Secure *bool `json:"secure"`
}
TargetHostPortView - A redirect target.
type ThirdPartyServiceView ¶
type ThirdPartyServiceView struct {
AvailabilityProfileId *int `json:"availabilityProfileId,omitempty"`
ExpectedHostname *string `json:"expectedHostname,omitempty"`
HostValue *string `json:"hostValue,omitempty"`
Id *string `json:"id,omitempty"`
LoadBalancingStrategyId *int `json:"loadBalancingStrategyId,omitempty"`
MaxConnections *int `json:"maxConnections,omitempty"`
Name *string `json:"name"`
Secure *bool `json:"secure,omitempty"`
SkipHostnameVerification *bool `json:"skipHostnameVerification,omitempty"`
Targets *[]*string `json:"targets"`
TrustedCertificateGroupId *int `json:"trustedCertificateGroupId,omitempty"`
UseProxy *bool `json:"useProxy,omitempty"`
}
ThirdPartyServiceView - A third-party service.
type ThirdPartyServicesView ¶
type ThirdPartyServicesView struct {
Items []*ThirdPartyServiceView `json:"items"`
}
ThirdPartyServicesView - A collection of third-party service items.
type TokenProviderSettingView ¶
type TokenProviderSettingView struct {
Type *string `json:"type,omitempty"`
UseThirdParty *bool `json:"useThirdParty,omitempty"`
}
TokenProviderSettingView - Settings for a token provider.
type TrustedCertView ¶
type TrustedCertView struct {
Alias *string `json:"alias"`
Expires *int `json:"expires,omitempty"`
Id *int `json:"id,omitempty"`
IssuerDn *string `json:"issuerDn"`
Md5sum *string `json:"md5sum"`
SerialNumber *string `json:"serialNumber"`
Sha1sum *string `json:"sha1sum"`
SignatureAlgorithm *string `json:"signatureAlgorithm"`
Status *string `json:"status"`
SubjectAlternativeNames []*GeneralName `json:"subjectAlternativeNames,omitempty"`
SubjectCn *string `json:"subjectCn,omitempty"`
SubjectDn *string `json:"subjectDn"`
ValidFrom *int `json:"validFrom,omitempty"`
}
TrustedCertView - A trusted certificate.
type TrustedCertificateGroupView ¶
type TrustedCertificateGroupView struct {
CertIds *[]*int `json:"certIds,omitempty"`
Id json.Number `json:"id,omitempty"`
IgnoreAllCertificateErrors *bool `json:"ignoreAllCertificateErrors,omitempty"`
Name *string `json:"name"`
RevocationChecking *RevocationCheckingView `json:"revocationChecking,omitempty"`
SkipCertificateDateCheck *bool `json:"skipCertificateDateCheck,omitempty"`
SystemGroup *bool `json:"systemGroup,omitempty"`
UseJavaTrustStore *bool `json:"useJavaTrustStore,omitempty"`
}
TrustedCertificateGroupView - A trusted certificate group.
type TrustedCertificateGroupsView ¶
type TrustedCertificateGroupsView struct {
Items []*TrustedCertificateGroupView `json:"items"`
}
TrustedCertificateGroupsView - A collection of trusted certificate group items.
type TrustedCertsView ¶
type TrustedCertsView struct {
Items []*TrustedCertView `json:"items"`
}
TrustedCertsView - A collection of trusted certificates.
type UnknownResourceSettingsView ¶
type UnknownResourceSettingsView struct {
AgentDefaultCacheTTL *int `json:"agentDefaultCacheTTL"`
AgentDefaultMode *string `json:"agentDefaultMode"`
AuditLevel *string `json:"auditLevel,omitempty"`
ErrorContentType *string `json:"errorContentType"`
ErrorStatusCode *int `json:"errorStatusCode"`
ErrorTemplateFile *string `json:"errorTemplateFile"`
}
UnknownResourceSettingsView - Global settings for unknown resources.
type UserPasswordView ¶
type UserPasswordView struct {
CurrentPassword *string `json:"currentPassword"`
Id json.Number `json:"id,omitempty"`
NewPassword *string `json:"newPassword"`
}
UserPasswordView - Settings to update a password.
type UserView ¶
type UserView struct {
Email *string `json:"email,omitempty"`
FirstLogin *bool `json:"firstLogin,omitempty"`
Id json.Number `json:"id,omitempty"`
ShowTutorial *bool `json:"showTutorial,omitempty"`
SlaAccepted *bool `json:"slaAccepted,omitempty"`
Username *string `json:"username"`
}
UserView - A user.
type UsersView ¶
type UsersView struct {
Items []*UserView `json:"items"`
}
UsersView - A collection of users.
type VersionDocClass ¶
type VersionDocClass struct {
Version *string `json:"version"`
}
VersionDocClass - A version.
type VirtualHostView ¶
type VirtualHostView struct {
AgentResourceCacheTTL *int `json:"agentResourceCacheTTL,omitempty"`
Host *string `json:"host"`
Id json.Number `json:"id,omitempty"`
KeyPairId *int `json:"keyPairId,omitempty"`
Port *int `json:"port"`
TrustedCertificateGroupId *int `json:"trustedCertificateGroupId,omitempty"`
}
VirtualHostView - A virtual host.
type VirtualHostsView ¶
type VirtualHostsView struct {
Items []*VirtualHostView `json:"items"`
}
VirtualHostsView - A collection of virtual hosts.
type WebSessionManagementView ¶
type WebSessionManagementView struct {
CookieName *string `json:"cookieName,omitempty"`
EncryptionAlgorithm *string `json:"encryptionAlgorithm,omitempty"`
Issuer *string `json:"issuer,omitempty"`
KeyRollEnabled *bool `json:"keyRollEnabled,omitempty"`
KeyRollPeriodInHours *int `json:"keyRollPeriodInHours,omitempty"`
NonceCookieTimeToLiveInMinutes *int `json:"nonceCookieTimeToLiveInMinutes,omitempty"`
SessionStateCookieName *string `json:"sessionStateCookieName,omitempty"`
SigningAlgorithm *string `json:"signingAlgorithm,omitempty"`
UpdateTokenWindowInSeconds *int `json:"updateTokenWindowInSeconds,omitempty"`
}
WebSessionManagementView - A web session management configuration.
type WebSessionView ¶
type WebSessionView struct {
Audience *string `json:"audience"`
CacheUserAttributes *bool `json:"cacheUserAttributes,omitempty"`
ClientCredentials *OAuthClientCredentialsView `json:"clientCredentials"`
CookieDomain *string `json:"cookieDomain,omitempty"`
CookieType *string `json:"cookieType,omitempty"`
EnableRefreshUser *bool `json:"enableRefreshUser,omitempty"`
FailOnUnsupportedPreservationContentType *bool `json:"failOnUnsupportedPreservationContentType"`
HttpOnlyCookie *bool `json:"httpOnlyCookie,omitempty"`
Id json.Number `json:"id,omitempty"`
IdleTimeoutInMinutes *int `json:"idleTimeoutInMinutes,omitempty"`
Name *string `json:"name"`
OidcLoginType *string `json:"oidcLoginType,omitempty"`
PfsessionStateCacheInSeconds *int `json:"pfsessionStateCacheInSeconds,omitempty"`
PkceChallengeType *string `json:"pkceChallengeType,omitempty"`
RefreshUserInfoClaimsInterval *int `json:"refreshUserInfoClaimsInterval,omitempty"`
RequestPreservationType *string `json:"requestPreservationType,omitempty"`
RequestProfile *bool `json:"requestProfile,omitempty"`
SameSite *string `json:"sameSite,omitempty"`
Scopes *[]*string `json:"scopes,omitempty"`
SecureCookie *bool `json:"secureCookie,omitempty"`
SendRequestedUrlToProvider *bool `json:"sendRequestedUrlToProvider,omitempty"`
SessionTimeoutInMinutes *int `json:"sessionTimeoutInMinutes,omitempty"`
ValidateSessionIsAlive *bool `json:"validateSessionIsAlive,omitempty"`
WebStorageType *string `json:"webStorageType,omitempty"`
}
WebSessionView - A web session.
type WebSessionsView ¶
type WebSessionsView struct {
Items []*WebSessionView `json:"items"`
}
WebSessionsView - A collection of web sessions.
type WebStorageTypesView ¶
type WebStorageTypesView struct {
Items []*ItemView `json:"items"`
}
WebStorageTypesView - A collection of valid web storage types.
type X509FileImportDocView ¶
type X509FileImportDocView struct {
Alias *string `json:"alias"`
FileData *string `json:"fileData"`
}
X509FileImportDocView - An X.509 certificate.